@@ -19,7 +19,8 @@ static const gchar *contributors[] = {
 	"Paolo Bacchilega",
 	"Timur I. Bakeyev",
 	"Szabolcs 'Shooby' B\xc3\xa1n",
-	"Martin Baulig",
+	"Emmanuele Bassi",
+        "Martin Baulig",
 	"Tom Bech",
 	"Andreas Beck",
 	"Carlos Amador Bedolla",
@@ -193,7 +194,8 @@ static const gchar *contributors[] = {
 	"Matthew Marjanovic",
 	"Heath Martin",
 	"Oliver Maruhn",
-	"Dave Mason",
+	"Fabio Marzocca",
+        "Dave Mason",
 	"James Mastros",
 	"Peter Mattis",
 	"Gordon Matzigkeit",
